KG2EInteraction
===============

.. currentmodule:: pykeen.nn.modules

.. autoclass:: KG2EInteraction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~KG2EInteraction.entity_shape
      ~KG2EInteraction.relation_shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~KG2EInteraction.func

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_shape
   .. autoattribute:: relation_shape

   .. rubric:: Methods Documentation

   .. automethod:: func
